import 'package:fast_immutable_collections/fast_immutable_collections.dart';
import 'package:notice/registry.dart';
import 'package:notice/src/notice_logger.dart';
import 'package:notice/src/notice_output.dart';
import 'package:notice/src/notice_reciever.dart';
import 'package:notice/src/notice_record.dart';

class Notice with NoticeLogger implements NoticeReceiver {
  Notice({
    this.parent,
    List<NoticeOutput> outputs = const [],
    this.breadcrumb,
    List<NoticeRegistry> registries = const [],
  }) : outputs = outputs.toIList() {
    for (final registry in registries) {
      registry.connect(this);
    }
  }

  /// creates a const sub notice that will simply log to the parent notice
  const Notice.childOf(this.parent, {this.breadcrumb}) : outputs = const IListConst([]);

  final NoticeReceiver? parent;
  final IList<NoticeOutput> outputs;
  final String? breadcrumb;
  
  @override
  void onRecord(NoticeRecord record) {
    if (breadcrumb != null) {
      record = record.copyWithBreadcrumb(breadcrumb!);
    }
    parent?.onRecord(record);
    _outputRecord(record);
  }

  void _outputRecord(NoticeRecord record) {
    for (final output in outputs) {
      output.onRecord(record);
    }
  }
}
